import { InspectorControls } from '@wordpress/block-editor';
import { TextareaControl, PanelBody, RangeControl, RadioControl, Button, ButtonGroup } from '@wordpress/components';

import GoogleMap from './googlemap';

const { Fragment } = wp.element;
const { __ } = wp.i18n;

const Edit = ({ className, attributes, setAttributes }) => {
    const { location, zoom, type, deskHeight, tabHeight, mobileHeight, deskPress, tabPress, phonePress } = attributes; 
    return(
        <Fragment>
            <InspectorControls>
                <PanelBody 
                    title={ __( 'Map Settings' ) }
                >
                    <TextareaControl
                        label={ __( 'Location Name' ) }
                        value={ location }
                        onChange={ ( location ) => setAttributes( { location } ) }
                        placeholder={ __( 'Enter a location' ) }
                    />
                    <RangeControl
						label={ __( 'Zoom Level' ) }
						beforeIcon="search"
						value={ zoom }
						onChange={ ( zoom ) => setAttributes( { zoom } ) }
						min={ 1 }
						max={ 22 }
					/>
                    <RadioControl
						label={ __( 'Map Type' ) }
						selected={ type }
						options={ [
							{ label: __('Roadmap'), value: 'm' },
							{ label: __('Satellite'), value: 'k' },
						] }
						onChange={ ( type ) => { setAttributes( { type } ) } }
					/>
                    <ButtonGroup style={{ marginBottom: '10px', float: 'right' }}>
                        <Button 
                            isSmall = { true }
                            isPressed={ deskPress }
                            onClick={ () => setAttributes({ 
                                deskPress: !deskPress, 
                                tabPress: false,
                                phonePress: false,
                            }) }
                        >
                            <span class="dashicons dashicons-desktop"></span>
                        </Button>
                        <Button 
                            isSmall = { true }
                            isPressed={ tabPress }
                            onClick={ () => setAttributes({ 
                                deskPress: false, 
                                tabPress: !tabPress,
                                phonePress: false,
                            }) }
                        >
                            <span class="dashicons dashicons-tablet"></span>
                        </Button>
                        <Button 
                            isSmall = { true }
                            isPressed={ phonePress }
                            onClick={ () => setAttributes({ 
                                deskPress: false, 
                                tabPress: false,
                                phonePress: !phonePress,
                            }) }
                        >
                            <span class="dashicons dashicons-smartphone"></span>
                        </Button>
                    </ButtonGroup>
                    {
                        deskPress &&
                        <RangeControl
                            label= {__('Map Height')}
                            beforeIcon='desktop'
                            value={ deskHeight }
                            onChange={ ( deskHeight ) => setAttributes( { deskHeight } ) }
                            min={ 1 }
                            max={ 2000 }
                        />
                    }
                    {
                        tabPress &&
                        <RangeControl
                            label={__('Map Height')}
                            beforeIcon='tablet'
                            value={ tabHeight }
                            onChange={ ( tabHeight ) => setAttributes( { tabHeight } ) }
                            min={ 1 }
                            max={ 2000 }
                        />
                    }
                    {
                        phonePress &&
                        <RangeControl
                            label={__('Map Height')}
                            beforeIcon='smartphone'
                            value={ mobileHeight }
                            onChange={ ( mobileHeight ) => setAttributes( { mobileHeight } ) }
                            min={ 1 }
                            max={ 2000 }
                        />
                    }
                </PanelBody>
            </InspectorControls>
            <div className={ `${className} dh-${deskHeight} th-${tabHeight} mh-${mobileHeight}` }>
                <GoogleMap
                    location={ location }
                    zoom={ zoom }
                    type={ type }
                    height= { deskHeight }
                />
            </div>
        </Fragment>
    );
}
export default Edit; 
