<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Blocks Class
*/

final class EMGB_Blocks_Class {

	private function __construct(){
		$this->emgb_define_constants(); 
		add_action( 'init', [ $this, 'emgb_blocks_assets' ] );
	}

	/**
	 * Singleton Instanace 
	*/

	public static function emgb_init(){
		static $instance = false; 
		if( ! $instance ) {
			$instance = new self();
		}
		return $instance;
	}

	/**
	 * Constants Define 
	*/
	public function emgb_define_constants(){
		define( 'EMGB_FILE', __FILE__ );
		define( 'EMGB_BLOCK', plugins_url( '', dirname( EMGB_FILE ) ) );
		define( 'EMGB_BLOCK_ASSETS', EMGB_BLOCK . '/dist' );
	}

	/**
	 * Blocks Registration 
	*/
	private function emgb_single_block_register( $block, $options=array() ){
		return register_block_type(
			'emgb/'. $block, 
			array_merge(
				array(
					'editor_script' => 'emgb-editor-script',
					'editor_style'  => 'emgb-editor-style',
					'style'         => 'emgb-style',
				),
				$options
			)
		);
	}

	/**
	 * Blocks Assets + Registration 
	*/
	public function emgb_blocks_assets(){

		// Frontend + Backend Style 
		wp_register_style(
			'emgb-style',
			EMGB_BLOCK_ASSETS . '/blocks.style.build.css',
			is_admin() ? array( 'wp-editor' ) : null,
			null
		);

		// Backend Style 
		wp_register_style(
			'emgb-editor-style',
			EMGB_BLOCK_ASSETS . '/blocks.editor.build.css',
			array( 'wp-edit-blocks' ),
			null
		);

		// Editor Scripts
		wp_register_script(
			'emgb-editor-script',
			EMGB_BLOCK_ASSETS . '/blocks.build.js',
			array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ),
			null,
			true
		);

		// Register Single Block 
		$this->emgb_single_block_register('map');
	
	}

}
/**
 * Initialization 
*/
function emgb_blocks(){
	return EMGB_Blocks_Class::emgb_init();
}

// kick-off the plugin 
emgb_blocks();